Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2422)

Unified Diff: content/renderer/media/android/webmediaplayer_android.h

Issue 1423163004: media: Replace DecryptorReadyCB with CdmReadyCB. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: comments addressed Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/media/android/webmediaplayer_android.h
diff --git a/content/renderer/media/android/webmediaplayer_android.h b/content/renderer/media/android/webmediaplayer_android.h
index bb338153f8fac37a3809049b86557513c440d313..7197b15887504946ceb0d52077c729a8c45cb9cf 100644
--- a/content/renderer/media/android/webmediaplayer_android.h
+++ b/content/renderer/media/android/webmediaplayer_android.h
@@ -321,15 +321,18 @@ class WebMediaPlayerAndroid : public blink::WebMediaPlayer,
void OnCdmContextReady(media::CdmContext* cdm_context);
// Sets the CDM. Should only be called when |is_player_initialized_| is true
- // and a new non-null |cdm_context_| is available. Fires |cdm_attached_cb_|
- // with the result after the CDM is attached.
+ // and a new non-null |cdm_context_| is available. Fires |cdm_attached_cb_| on
+ // the main thread with the result after the CDM is attached.
void SetCdmInternal(const media::CdmAttachedCB& cdm_attached_cb);
- // Requests that this object notifies when a decryptor is ready through the
- // |decryptor_ready_cb| provided.
- // If |decryptor_ready_cb| is null, the existing callback will be fired with
+ // Called when the CDM is attached.
+ void OnCdmAttached(const media::CdmAttachedCB& cdm_attached_cb, bool success);
+
+ // Requests that this object notifies when a CDM is ready through the
+ // |cdm_ready_cb| provided.
+ // If |cdm_ready_cb| is null, the existing callback will be fired with
// NULL immediately and reset.
- void SetDecryptorReadyCB(const media::DecryptorReadyCB& decryptor_ready_cb);
+ void SetCdmReadyCB(const media::CdmReadyCB& cdm_ready_cb);
// Called when the ContentDecryptionModule has been attached to the
// pipeline/decoders.
@@ -510,7 +513,7 @@ class WebMediaPlayerAndroid : public blink::WebMediaPlayer,
// side CDM will be used. This is similar to WebMediaPlayerImpl. For other key
// systems, a browser side CDM will be used and we set CDM by calling
// player_manager_->SetCdm() directly.
- media::DecryptorReadyCB decryptor_ready_cb_;
+ media::CdmReadyCB cdm_ready_cb_;
SkBitmap bitmap_;
« no previous file with comments | « content/renderer/media/android/media_source_delegate.cc ('k') | content/renderer/media/android/webmediaplayer_android.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698